@@ -1,4 +1,5 @@
 import asyncio
+import hashlib
 from functools import partial
 from pathlib import Path
 
@@ -9,20 +10,29 @@ from mootdx.utils import TqdmUpTo
 
 def download(downdir, filename):
     with TqdmUpTo(unit='B', unit_scale=True, miniters=1, ascii=True) as t:
-        financial.Financial().fetch_and_parse(report_hook=t.update_to, filename=filename, downdir=downdir)
+        financial.Financial().fetch_only(report_hook=t.update_to, filename=filename, downdir=downdir)
 
     return True
 
 
-async def fetch_file(downdir, filename):
-    result = await asyncio.get_event_loop().run_in_executor(None, partial(financial.Financial().fetch_only, report_hook=None, filename=filename, downdir=downdir))
+async def fetch_file(downdir, file_obj):
+    filepath = Path(downdir) / file_obj['filename']
+
+    # 判断文件是否存在, 验证文件名和哈希值
+    if filepath.exists():
+        if file_obj['hash'] == hashlib.md5(open(filepath, 'rb').read()).hexdigest():
+            log.warning(f'文件已经存在: {filepath}')
+            return None
+
+    result = await asyncio.get_event_loop().run_in_executor(None, partial(financial.Financial().fetch_only, report_hook=None, filename=file_obj['filename'], downdir=downdir))
     return result
 
 
 class Affair(object):
     @staticmethod
     def parse(downdir='.', filename=None):
-        """ 按目录解析文件
+        """
+        按目录解析文件
 
         :param downdir:
         :param filename:
@@ -44,19 +54,24 @@ class Affair(object):
 
     @staticmethod
     def files():
-        """ 财务文件列表
+        """
+        财务文件列表
 
-        :return: object
+        :return:
         """
 
-        return financial.FinancialList().fetch_and_parse()
+        history = financial.FinancialList()
+        results = history.fetch_and_parse()
+
+        return results
 
     @staticmethod
     def fetch(downdir='.', filename=None):
-        """ 财务数据下载
+        """
+        财务数据下载
 
-        :param downdir: 下载路径
-        :param filename: 文件名
+        :param downdir:
+        :param filename:
         :return:
         """
 
@@ -69,17 +84,17 @@ class Affair(object):
 
         if filename:
             log.info('下载文件 {}.'.format(filename))
-            crawler.fetch_only(report_hook=None, filename=filename, downdir=downdir)
+
+            with TqdmUpTo(unit='B', unit_scale=True, miniters=1, ascii=True) as t:
+                crawler.fetch_only(report_hook=t.update_to, filename=filename, downdir=downdir)
+
             return True
 
-        list_data = history.fetch_and_parse()
         tasks = []
+        event = asyncio.get_event_loop()
 
-        loop = asyncio.get_event_loop()
-
-        for x in list_data:
-            task = loop.create_task(fetch_file(filename=x['filename'], downdir=downdir))
+        for x in history.fetch_and_parse():
+            task = event.create_task(fetch_file(file_obj=x, downdir=downdir))
             tasks.append(task)
 
-        loop = asyncio.get_event_loop()
-        loop.run_until_complete(asyncio.wait(tasks))
+        event.run_until_complete(asyncio.wait(tasks))
