@@ -17,7 +17,8 @@ from ..logger import logger
 class FinancialReader(object):
     @staticmethod
     def to_data(filename):
-        """ 读取历史财务数据文件，并返回pandas结果 ， 类似 `gpcw20171231.zip` 格式，具体字段含义参考
+        """
+        读取历史财务数据文件，并返回pandas结果 ， 类似 `gpcw20171231.zip` 格式，具体字段含义参考
 
         https://github.com/rainx/pytdx/issues/133
 
@@ -25,16 +26,19 @@ class FinancialReader(object):
         :return: pandas DataFrame 格式的历史财务数据
         """
 
-        with open(filename, 'rb') as fp:
-            data = Financial().parse(download_file=fp)
+        crawler = Financial()
 
-        return Financial().to_df(data)
+        with open(filename, 'rb') as fp:
+            data = crawler.parse(download_file=fp)
+
+        return crawler.to_df(data)
 
 
 class FinancialList(BaseFinancial):
 
     def content(self, report_hook=None, downdir=None, proxies=None, chunk_size=1024 * 50, *args, **kwargs):
-        """ 解析财务文件
+        """
+        解析财务文件
 
         :param report_hook: 钩子回调函数
         :param downdir: 要解析的文件夹
@@ -46,6 +50,7 @@ class FinancialList(BaseFinancial):
         """
 
         tmp = tempfile.NamedTemporaryFile(delete=True)
+
         api = TdxHq_API(**kwargs)
         api.need_setup = False
 
@@ -58,7 +63,8 @@ class FinancialList(BaseFinancial):
             return download_file
 
     def parse(self, download_file, *args, **kwargs):
-        """ 解析财务文件
+        """
+        解析财务文件
 
         :param download_file:
         :param args:
@@ -66,23 +72,29 @@ class FinancialList(BaseFinancial):
         :return:
         """
 
+        with download_file:
+            content = download_file.read()
+            content = content.decode('utf-8')
+
         def l2d(i):
             return {'filename': i[0], 'hash': i[1], 'filesize': int(i[2])}
 
-        with download_file:
-            content = download_file.read().decode('utf-8').strip().split('\n')
+        if content:
+            content = content.strip().split('\n')
+            return [l2d(i) for i in [line.strip().split(',') for line in content]]
 
-        return [l2d(i) for i in [line.strip().split(',') for line in content]] if content else None
+        return None
 
 
 class Financial(BaseFinancial):
 
-    def content(self, report_hook=None, downdir=None, proxies=None, chunk_size=1024 * 50, *args, **kwargs):
-        """ 解析财务文件
+    def content(self, report_hook=None, downdir=None, proxies=None, chunk_size=51200, *args, **kwargs):
+        """
+        解析财务文件
 
         :param report_hook: 钩子回调函数
         :param downdir: 要解析的文件夹
-        :param proxies:
+        :param proxies: 代理配置
         :param chunk_size:
         :param args:
         :param kwargs:
@@ -93,10 +105,6 @@ class Financial(BaseFinancial):
         downfile = str(Path(downdir) / filename)
         filesize = kwargs.get('filesize') if kwargs.get('filesize') else 0
 
-        if Path(downfile).exists():
-            log.warning('{}: Already exists', filename)
-            return open(downfile, 'rb')
-
         log.info('{}: start download...', filename)
 
         if not filename:
@@ -118,7 +126,8 @@ class Financial(BaseFinancial):
             return download_file
 
     def parse(self, download_file, *args, **kwargs):
-        """ 解析财务文件
+        """
+        解析财务文件
 
         :param download_file: 要解析的文件
         :param args:
@@ -136,7 +145,7 @@ class Financial(BaseFinancial):
 
             tmpdir = Path(tmpdir_root, subdir_name)
             shutil.rmtree(tmpdir, ignore_errors=True)
-            tmpdir.mkdir(parents=True)
+            Path(tmpdir).mkdir(parents=True)
 
             shutil.unpack_archive(download_file.name, extract_dir=tmpdir)
 
@@ -157,7 +166,6 @@ class Financial(BaseFinancial):
 
         header_size = calcsize(header_pack_format)
         stock_item_size = calcsize('<6s1c1L')
-
         data_header = datfile.read(header_size)
         stock_header = unpack(header_pack_format, data_header)
 
@@ -173,19 +181,14 @@ class Financial(BaseFinancial):
 
         for stock_idx in range(0, max_count):
             datfile.seek(header_size + stock_idx * calcsize('<6s1c1L'))
-
             si = datfile.read(stock_item_size)
             stock_item = unpack('<6s1c1L', si)
-
             code = stock_item[0].decode('utf-8')
-            foa = stock_item[2]
-
-            datfile.seek(foa)
+            datfile.seek(stock_item[2])
 
             info_data = datfile.read(calcsize(report_pack_format))
             cw_info = unpack(report_pack_format, info_data)
             one_record = (code, report_date) + cw_info
-
             results.append(one_record)
 
         if download_file.name.endswith('.zip'):
@@ -219,14 +222,3 @@ class Financial(BaseFinancial):
         logger.debug(df)
 
         return df
-
-    def fetch_only(self, report_hook=None, downdir=None, chunk_size=51200, *args, **kwargs):
-        """ function to get data , 参考 https://docs.python.org/3/library/urllib.request.html#module-urllib.request
-
-        :param report_hook 使用urllib.request 的report_hook 来汇报下载进度
-        :param downdir 数据文件下载的地址，如果没有提供，则下载到临时文件中，并在解析之后删除
-        :param chunk_size chunk_size
-        :return: 解析之后的数据结果
-        """
-
-        return self.content(report_hook=report_hook, downdir=downdir, chunk_size=chunk_size, *args, **kwargs).close()
